@@ -1,11 +1,11 @@
-// $Id: decorator.java,v 1.32 2009/11/20 22:22:09 cmzmasek Exp $
+// $Id:
 // FORESTER -- software libraries and applications
 // for evolutionary biology research and applications.
 //
 // Copyright (C) 2008-2009 Christian M. Zmasek
 // Copyright (C) 2008-2009 Burnham Institute for Medical Research
 // All rights reserved
-// 
+//
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
 // License as published by the Free Software Foundation; either
@@ -15,12 +15,12 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 // Lesser General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 //
-// Contact: cmzmasek@yahoo.com
+// Contact: phylosoft @ gmail . com
 // WWW: www.phylosoft.org/forester
 
 package org.forester.application;
@@ -32,6 +32,7 @@ import java.util.List;
 import java.util.Map;
 
 import org.forester.io.parsers.PhylogenyParser;
+import org.forester.io.parsers.util.ParserUtils;
 import org.forester.io.writers.PhylogenyWriter;
 import org.forester.phylogeny.Phylogeny;
 import org.forester.phylogeny.data.Identifier;
@@ -76,7 +77,7 @@ public final class decorator {
     private static void argumentsError() {
         System.out.println();
         System.out.println( decorator.PRG_NAME + " -" + ADVANCED_TABLE_OPTION + " | -f=<c> <phylogenies infile> "
-                + "<mapping table file> <phylogenies outfile>" );
+                + "[mapping table file] <phylogenies outfile>" );
         System.out.println();
         System.out.println( "options:" );
         System.out.println();
@@ -291,7 +292,7 @@ public final class decorator {
         Phylogeny[] phylogenies = null;
         try {
             final PhylogenyFactory factory = ParserBasedPhylogenyFactory.getInstance();
-            final PhylogenyParser pp = ForesterUtil.createParserDependingOnFileType( phylogenies_infile, true );
+            final PhylogenyParser pp = ParserUtils.createParserDependingOnFileType( phylogenies_infile, true );
             phylogenies = factory.create( phylogenies_infile, pp );
         }
         catch ( final Exception e ) {
@@ -305,8 +306,8 @@ public final class decorator {
                 mapping_table = BasicTableParser.parse( mapping_infile, separator, decorator.USE_FIRST_SEPARATOR_ONLY );
             }
             catch ( final Exception e ) {
-                ForesterUtil.fatalError( decorator.PRG_NAME, "failed to read [" + mapping_infile + "] ["
-                        + e.getMessage() + "]" );
+                ForesterUtil.fatalError( decorator.PRG_NAME,
+                                         "failed to read [" + mapping_infile + "] [" + e.getMessage() + "]" );
             }
             if ( ( key_column < 0 ) || ( key_column >= mapping_table.getNumberOfColumns() ) ) {
                 ForesterUtil.fatalError( decorator.PRG_NAME, "illegal value for key column" );
@@ -343,8 +344,8 @@ public final class decorator {
                     table = PhylogenyDecorator.parseMappingTable( mapping_infile );
                 }
                 catch ( final IOException e ) {
-                    ForesterUtil.fatalError( decorator.PRG_NAME, "failed to read \"" + mapping_infile + "\" ["
-                            + e.getMessage() + "]" );
+                    ForesterUtil.fatalError( decorator.PRG_NAME,
+                                             "failed to read \"" + mapping_infile + "\" [" + e.getMessage() + "]" );
                 }
                 PhylogenyDecorator.decorate( phylogenies,
                                              table,
