@@ -1,4 +1,4 @@
-// $Id: rio.java,v 1.11 2010/01/16 02:15:34 cmzmasek Exp $
+// $Id:
 // FORESTER -- software libraries and applications
 // for evolutionary biology research and applications.
 //
@@ -7,7 +7,7 @@
 // Copyright (C) 2000-2001 Washington University School of Medicine
 // and Howard Hughes Medical Institute
 // All rights reserved
-// 
+//
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
 // License as published by the Free Software Foundation; either
@@ -17,12 +17,12 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 // Lesser General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 //
-// Contact: cmzmasek@yahoo.com
+// Contact: phylosoft @ gmail . com
 // WWW: www.phylosoft.org/forester
 
 package org.forester.application;
@@ -44,6 +44,7 @@ import org.forester.phylogeny.factories.PhylogenyFactory;
 import org.forester.phylogeny.iterators.PreorderTreeIterator;
 import org.forester.sdi.DistanceCalculator;
 import org.forester.sdi.RIO;
+import org.forester.sdi.SDIException;
 import org.forester.sdi.SDIR;
 import org.forester.util.ForesterUtil;
 
@@ -145,7 +146,7 @@ public class rio {
                                                     final int warn_no_orthos,
                                                     final double warn_one_ortho,
                                                     final int bootstraps,
-                                                    final double t_orthologs_dc ) throws IOException {
+                                                    final double t_orthologs_dc ) throws IOException, SDIException {
         Phylogeny consensus_tree = null;
         Phylogeny
         // to be a consensus tree.
