@@ -22,6 +22,10 @@
  */
 package org.biojava.bio.structure;
 
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.IOException;
+import java.io.InputStream;
 import java.io.StringWriter;
 import java.util.ArrayList;
 import java.util.HashMap;
@@ -31,13 +35,17 @@ import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-
 import java.util.logging.Level;
 import java.util.logging.Logger;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
 import org.biojava.bio.structure.align.util.AtomCache;
+import org.biojava.bio.structure.io.PDBFileParser;
+import org.biojava.bio.structure.io.mmcif.chem.PolymerType;
+import org.biojava.bio.structure.io.mmcif.chem.ResidueType;
+import org.biojava.bio.structure.io.mmcif.model.ChemComp;
+import org.biojava.bio.structure.io.util.FileDownloadUtils;
 
 
 /**
@@ -58,7 +66,7 @@ public class StructureTools {
 
 	public static final String oAtomName = "O";
 
-	public static final String cbAtomName = "CB";
+	public static final String cbAtomName = " CB ";
 
 
 	/** The names of the Atoms that form the backbone.
@@ -279,6 +287,30 @@ public class StructureTools {
 		return (Atom[]) atoms.toArray(new Atom[atoms.size()]);	
 	}
 
+	/**
+	 * Returns and array of all non-Hydrogen atoms in the given Structure, 
+	 * optionally including HET atoms or not
+	 * @param s
+	 * @param hetAtoms if true HET atoms are included in array, if false they are not
+	 * @return
+	 */
+	public static final Atom[] getAllNonHAtomArray(Structure s, boolean hetAtoms) {
+		List<Atom> atoms = new ArrayList<Atom>();
+
+		
+		AtomIterator iter = new AtomIterator(s);
+		while (iter.hasNext()){
+			Atom a = iter.next();
+			if (a.getElement()==Element.H) continue;
+			
+			Group g = a.getGroup();
+			
+			if (!hetAtoms && g.getType().equals(GroupType.HETATM)) continue;
+			
+			atoms.add(a);
+		}
+		return (Atom[]) atoms.toArray(new Atom[atoms.size()]);			
+	}
 
 	private static void extractCAatoms(String[] atomNames, List<Chain> chains,
 			List<Atom> atoms) {
@@ -694,6 +726,7 @@ public class StructureTools {
 		newS.setConnections(s.getConnections());
 		newS.setSSBonds(s.getSSBonds());
 		newS.setSites(s.getSites());
+		newS.setCrystallographicInfo(s.getCrystallographicInfo());
 		newS.getPDBHeader().setDescription("subset of " + s.getPDBCode() + " " + s.getPDBHeader().getDescription() );
 
 		if ( chainNr < 0 ) {
@@ -768,7 +801,7 @@ public class StructureTools {
 		newS.setNmr(s.isNmr());
 		newS.setBiologicalAssembly(s.isBiologicalAssembly());
 		newS.getPDBHeader().setDescription("sub-range " + ranges + " of "  + newS.getPDBCode() + " " + s.getPDBHeader().getDescription());
-
+		newS.setCrystallographicInfo(s.getCrystallographicInfo());
 		// TODO The following should be only copied for atoms which are present in the range.
 		//newS.setCompounds(s.getCompounds());
 		//newS.setConnections(s.getConnections());
@@ -784,7 +817,7 @@ public class StructureTools {
 
 		// parse the ranges, adding the specified residues to newS
 		for ( String r: rangS){
-			//System.out.println(">"+r+"<");
+
 			// Match a single range, eg "A_4-27"
 
 			Matcher matcher = pdbNumRangeRegex.matcher(r);
@@ -794,9 +827,15 @@ public class StructureTools {
 			String chainId = matcher.group(1);
 			Chain chain;
 
-			if(chainId.equals("_") && struc.size() == 1) {
+			if(chainId.equals("_") ) {
 				// Handle special case of "_" chain for single-chain proteins
 				chain = struc.getChain(0);
+
+				if(struc.size() != 1) {
+					// SCOP 1.71 uses this for some proteins with multiple chains
+					// Print a warning in this ambiguous case
+					System.err.format("WARNING multiple possible chains match '_'. Using chain %s.%n",chain.getChainID());
+				}
 			} else {
 				// Explicit chain
 				chain = struc.getChainByPDB(chainId);
@@ -807,6 +846,7 @@ public class StructureTools {
 			String pdbresnumStart = matcher.group(2);
 			String pdbresnumEnd   = matcher.group(3);
 
+				
 			if ( ! firstRange){
 				name.append( ",");
 			} else {
@@ -819,7 +859,11 @@ public class StructureTools {
 					pdbresnumStart = pdbresnumStart.substring(1);
 				if(pdbresnumEnd.charAt(0) == '+')
 					pdbresnumEnd = pdbresnumEnd.substring(1);
-				groups = chain.getGroupsByPDB(pdbresnumStart, pdbresnumEnd);
+				
+				ResidueNumber pdbresnum1 = ResidueNumber.fromString(pdbresnumStart);
+				ResidueNumber pdbresnum2 = ResidueNumber.fromString(pdbresnumEnd);
+				
+				groups = chain.getGroupsByPDB(pdbresnum1, pdbresnum2);
 
 				name.append( chainId + AtomCache.UNDERSCORE + pdbresnumStart+"-" + pdbresnumEnd);
 
@@ -828,6 +872,7 @@ public class StructureTools {
 				groups = chain.getAtomGroups().toArray(new Group[chain.getAtomGroups().size()]);
 				name.append(chainId);
 			}
+						
 			firstRange = true;
 
 			// Create new chain, if needed
@@ -924,99 +969,64 @@ public class StructureTools {
 		return chain.getGroupByPDB(pdbResNum);
 	}
 
-	/*
-	 * Returns a List of Groups in a structure within the distance specified of a given group.
+
+	/**
+	 * Finds Groups in {@code structure} that contain at least one Atom that is within {@code radius} Angstroms of {@code centroid}.
+	 * @param structure The structure from which to find Groups
+	 * @param centroid The centroid of the shell
+	 * @param excludeResidues A list of ResidueNumbers to exclude
+	 * @param radius The radius from {@code centroid}, in Angstroms
+	 * @param includeWater Whether to include Groups whose <em>only</em> atoms are water
+	 * @param useAverageDistance When set to true, distances are the arithmetic mean (1-norm) of the distances of atoms that belong to the group and that are within the shell; otherwise, distances are the minimum of these values
+	 * @return A map of Groups within (or partially within) the shell, to their distances in Angstroms
 	 */
-	public static List<Group> getGroupsWithinShell(Structure structure, Group group, double distance, boolean includeWater) {
-		Set<Group> returnSet = new LinkedHashSet<Group>();
+	public static Map<Group,Double> getGroupDistancesWithinShell(Structure structure, Atom centroid, Set<ResidueNumber> excludeResidues, double radius, boolean includeWater, boolean useAverageDistance) {
 
-		//square the distance to use as a comparison against getDistanceFast which returns the square of a distance.
-		distance = distance * distance;
+		// for speed, we avoid calculating square roots
+		radius = radius * radius;
 
-		for (Atom atomA : group.getAtoms()) {
-			for (Chain chain : structure.getChains()) {
-				for (Group chainGroup : chain.getAtomGroups()) {
-					//                        System.out.println("Checking group: " + chainGroup);
-					if (chainGroup.getResidueNumber().equals(group.getResidueNumber())) {
-						continue;
-					}
-					else if (!includeWater && chainGroup.getPDBName().equals("HOH")) {
-						continue;
-					}
-					else {
-						for (Atom atomB : chainGroup.getAtoms()) {
-							try {
-								//use getDistanceFast as we are doing a lot of comparisons
-								double dist = Calc.getDistanceFast(atomA, atomB);
-								if (dist <= distance) {
-									returnSet.add(chainGroup);
-									//                                    System.out.println(String.format("%s within %s of %s", atomB, dist, atomA));
-									break;
-								}
+		Map<Group,Double> distances = new HashMap<Group,Double>();
+		
+		// we only need this if we're averaging distances
+		// note that we can't use group.getAtoms().size() because some the group's atoms be outside the shell
+		Map<Group,Integer> atomCounts = new HashMap<Group,Integer>();
 
-							} catch (StructureException ex) {
-								Logger.getLogger(StructureTools.class.getName()).log(Level.SEVERE, null, ex);
-							}
+		for (Chain chain : structure.getChains()) {
+			groupLoop: for (Group chainGroup : chain.getAtomGroups()) {
 
-						}
-					}
+				// exclude water
+				if (!includeWater && chainGroup.getPDBName().equals("HOH")) continue;
+				
+				// check blacklist of residue numbers
+				for (ResidueNumber rn : excludeResidues) {
+					if (rn.equals(chainGroup.getResidueNumber())) continue groupLoop;
 				}
-			}
-		}
-		List<Group> returnList = new ArrayList<Group>();
-		returnList.addAll(returnSet);
-		return returnList;
-	}
-
-	/*
-	 * Very simple distance-based bond calculator. Will give approximations,
-	 * but do not rely on this to be chemically correct.
-	 */
-	public static List<Bond> findBonds(Group group, List<Group> groups) {
-		List<Bond> bondList = new ArrayList<Bond>();
-		for (Atom atomA : group.getAtoms()) {
-			for (Group groupB : groups) {
-				if (groupB.getType().equals(GroupType.HETATM)) {
-					continue;
-				}
-				for (Atom atomB : groupB.getAtoms()) {
+				
+				for (Atom testAtom : chainGroup.getAtoms()) {
+					
 					try {
-						double dist = Calc.getDistance(atomA, atomB);
-						BondType bondType = BondType.UNDEFINED;
-						if (dist <= 2) {
-							bondType = BondType.COVALENT;
-							Bond bond = new Bond(dist, bondType, group, atomA, groupB, atomB);
-							bondList.add(bond);
-							//                                    System.out.println(String.format("%s within %s of %s", atomB, dist, atomA));
-						}
-						else if (dist <= 3.25) {
-
-							if (isHbondDonorAcceptor(atomA) && isHbondDonorAcceptor(atomB)) {
-								bondType = BondType.HBOND;
-							}
-							else if (atomA.getElement().isMetal() && isHbondDonorAcceptor(atomB)) {
-								bondType = BondType.METAL;
-							}
-							else if (atomA.getElement().equals(Element.C) && atomB.getElement().equals(Element.C)) {
-								bondType = BondType.HYDROPHOBIC;
-							}
-							//not really interested in 'undefined' types
-							if (bondType != BondType.UNDEFINED) {
-								Bond bond = new Bond(dist, bondType, group, atomA, groupB, atomB);
-								bondList.add(bond);
-							}
-							//                                    System.out.println(String.format("%s within %s of %s", atomB, dist, atomA));
-						} else if (dist <= 3.9) {
-							if (atomA.getElement().equals(Element.C) && atomB.getElement().equals(Element.C)) {
-								bondType = BondType.HYDROPHOBIC;
-							}
-							//not really interested in 'undefined' types
-							if (bondType != BondType.UNDEFINED) {
-								Bond bond = new Bond(dist, bondType, group, atomA, groupB, atomB);
-								bondList.add(bond);
+						
+						// use getDistanceFast as we are doing a lot of comparisons
+						double dist = Calc.getDistanceFast(centroid, testAtom);
+						
+						// if we're the shell
+						if (dist <= radius) {
+							if (!distances.containsKey(chainGroup)) distances.put(chainGroup, Double.POSITIVE_INFINITY);
+							if (useAverageDistance) {
+								// sum the distance; we'll divide by the total number later
+								// here, we CANNOT use fastDistance (distance squared) because we want the arithmetic mean
+								distances.put(chainGroup, distances.get(chainGroup) + Math.sqrt(dist));
+								if (!atomCounts.containsKey(chainGroup)) atomCounts.put(chainGroup, 0);
+								atomCounts.put(chainGroup, atomCounts.get(chainGroup) + 1);
+							} else {
+								// take the minimum distance among all atoms of chainGroup
+								// note that we can't break here because we might find a smaller distance
+								if (dist < distances.get(chainGroup)) {
+									distances.put(chainGroup, dist);
+								}
 							}
 						}
-
+						
 					} catch (StructureException ex) {
 						Logger.getLogger(StructureTools.class.getName()).log(Level.SEVERE, null, ex);
 					}
@@ -1024,24 +1034,147 @@ public class StructureTools {
 				}
 			}
 		}
-
-
-		return bondList;
-	}
-
-	private static boolean isHbondDonorAcceptor(Atom atom) {
-		if (hBondDonorAcceptors.contains(atom.getElement())) {
-			return true;
+		
+		if (useAverageDistance) {
+			for (Map.Entry<Group,Double> entry : distances.entrySet()) {
+				int count = atomCounts.get(entry.getKey());
+				distances.put(entry.getKey(), entry.getValue() / count);
+			}
+		} else {
+			// in this case we used getDistanceFast
+			for (Map.Entry<Group,Double> entry : distances.entrySet()) {
+				distances.put(entry.getKey(), Math.sqrt(entry.getValue()));
+			}
 		}
-		return false;
+		
+		return distances;
+		
 	}
 
+	public static Set<Group> getGroupsWithinShell(Structure structure, Atom atom, Set<ResidueNumber> excludeResidues, double distance, boolean includeWater) {
+
+		//square the distance to use as a comparison against getDistanceFast which returns the square of a distance.
+		distance = distance * distance;
+
+		Set<Group> returnSet = new LinkedHashSet<Group>();
+		for (Chain chain : structure.getChains()) {
+			groupLoop: for (Group chainGroup : chain.getAtomGroups()) {
+				if (!includeWater && chainGroup.getPDBName().equals("HOH")) continue;
+				for (ResidueNumber rn : excludeResidues) {
+					if (rn.equals(chainGroup.getResidueNumber())) continue groupLoop;
+				}
+				for (Atom atomB : chainGroup.getAtoms()) {
+					try {
+						//use getDistanceFast as we are doing a lot of comparisons
+						double dist = Calc.getDistanceFast(atom, atomB);
+						if (dist <= distance) {
+							returnSet.add(chainGroup);
+							break;
+						}
+					} catch (StructureException ex) {
+						Logger.getLogger(StructureTools.class.getName()).log(Level.SEVERE, null, ex);
+					}
+
+				}
+			}
+		}
+		return returnSet;
+	}
+
+	/*
+	 * Returns a List of Groups in a structure within the distance specified of a given group.
+	 */
+	public static List<Group> getGroupsWithinShell(Structure structure, Group group, double distance, boolean includeWater) {
+
+		List<Group> returnList = new ArrayList<Group>();
+
+		Set<ResidueNumber> excludeGroups = new HashSet<ResidueNumber>();
+		excludeGroups.add(group.getResidueNumber());
+		for (Atom atom : group.getAtoms()) {
+			Set<Group> set = getGroupsWithinShell(structure, atom, excludeGroups, distance, includeWater);
+			returnList.addAll(set);
+		}
+
+		return returnList;
+	}
+
+	//	This code relies on an old version of the Bond class.
+	//	
+	//	/*
+	//	 * Very simple distance-based bond calculator. Will give approximations,
+	//	 * but do not rely on this to be chemically correct.
+	//	 */
+	//	public static List<Bond> findBonds(Group group, List<Group> groups) {
+	//		List<Bond> bondList = new ArrayList<Bond>();
+	//		for (Atom atomA : group.getAtoms()) {
+	//			for (Group groupB : groups) {
+	//				if (groupB.getType().equals(GroupType.HETATM)) {
+	//					continue;
+	//				}
+	//				for (Atom atomB : groupB.getAtoms()) {
+	//					try {
+	//						double dist = Calc.getDistance(atomA, atomB);
+	//						BondType bondType = BondType.UNDEFINED;
+	//						if (dist <= 2) {
+	//							bondType = BondType.COVALENT;
+	//							Bond bond = new Bond(dist, bondType, group, atomA, groupB, atomB);
+	//							bondList.add(bond);
+	//							//                                    System.out.println(String.format("%s within %s of %s", atomB, dist, atomA));
+	//						}
+	//						else if (dist <= 3.25) {
+	//
+	//							if (isHbondDonorAcceptor(atomA) && isHbondDonorAcceptor(atomB)) {
+	//								bondType = BondType.HBOND;
+	//							}
+	//							else if (atomA.getElement().isMetal() && isHbondDonorAcceptor(atomB)) {
+	//								bondType = BondType.METAL;
+	//							}
+	//							else if (atomA.getElement().equals(Element.C) && atomB.getElement().equals(Element.C)) {
+	//								bondType = BondType.HYDROPHOBIC;
+	//							}
+	//							//not really interested in 'undefined' types
+	//							if (bondType != BondType.UNDEFINED) {
+	//								Bond bond = new Bond(dist, bondType, group, atomA, groupB, atomB);
+	//								bondList.add(bond);
+	//							}
+	//							//                                    System.out.println(String.format("%s within %s of %s", atomB, dist, atomA));
+	//						} else if (dist <= 3.9) {
+	//							if (atomA.getElement().equals(Element.C) && atomB.getElement().equals(Element.C)) {
+	//								bondType = BondType.HYDROPHOBIC;
+	//							}
+	//							//not really interested in 'undefined' types
+	//							if (bondType != BondType.UNDEFINED) {
+	//								Bond bond = new Bond(dist, bondType, group, atomA, groupB, atomB);
+	//								bondList.add(bond);
+	//							}
+	//						}
+	//
+	//					} catch (StructureException ex) {
+	//						Logger.getLogger(StructureTools.class.getName()).log(Level.SEVERE, null, ex);
+	//					}
+	//
+	//				}
+	//			}
+	//		}
+	//
+	//
+	//		return bondList;
+	//	}
+	//
+	//	private static boolean isHbondDonorAcceptor(Atom atom) {
+	//		if (hBondDonorAcceptors.contains(atom.getElement())) {
+	//			return true;
+	//		}
+	//		return false;
+	//	}
+
 	/** Remove all models from a Structure and keep only the first
 	 * 
 	 * @param s original Structure
 	 * @return a structure that contains only  the first model
 	 * @since 3.0.5
 	 */
+	@SuppressWarnings("deprecation")
 	public static Structure removeModels(Structure s){
 		if ( ! s.isNmr())
 			return s;
@@ -1054,17 +1187,103 @@ public class StructureTools {
 
 		n.setPDBCode(s.getPDBCode());
 		n.setName(s.getName());
+
+		// we are calling this legacy menthod for backwards compatibility
 		n.setHeader(s.getHeader());
 		//TODO: do deep copying of data!
 		n.setPDBHeader(s.getPDBHeader());
 		n.setDBRefs(s.getDBRefs());
 		n.setConnections(s.getConnections());
 		n.setSites(s.getSites());
-		
+		n.setCrystallographicInfo(s.getCrystallographicInfo());
+
 		n.setChains(s.getModel(0));
-		
+
 		return n;
 
 
 	}
+
+	/** Removes all polymeric and solvent groups from a list of groups
+	 * 
+	 */
+	public static List<Group> filterLigands(List<Group> allGroups){
+		//String prop = System.getProperty(PDBFileReader.LOAD_CHEM_COMP_PROPERTY);
+
+		//    if ( prop == null || ( ! prop.equalsIgnoreCase("true"))){
+		//      System.err.println("You did not specify PDBFileReader.setLoadChemCompInfo, need to fetch Chemical Components anyways.");
+		//    }
+
+
+		List<Group> groups = new ArrayList<Group>();
+		for ( Group g: allGroups) {
+
+			ChemComp cc = g.getChemComp();
+
+			if ( ResidueType.lPeptideLinking.equals(cc.getResidueType()) ||
+					PolymerType.PROTEIN_ONLY.contains(cc.getPolymerType()) ||
+					PolymerType.POLYNUCLEOTIDE_ONLY.contains(cc.getPolymerType())
+					){
+				continue;
+			}
+			if ( ! g.isWater()) {
+				//System.out.println("not a prot, nuc or solvent : " + g.getChemComp());
+				groups.add(g);
+			}
+		}
+
+		return groups;
+	}
+
+
+
+
+	/**
+	 * Short version of {@link #getStructure(String, PDBFileParser, AtomCache)}
+	 * which creates new parsers when needed
+	 * @param name
+	 * @return
+	 * @throws IOException
+	 * @throws StructureException
+	 */
+	public static Structure getStructure(String name) throws IOException, StructureException {
+		return StructureTools.getStructure(name,null,null);
+	}
+	/**
+	 * Flexibly get a structure from an input String. The intent of this method
+	 * is to allow any reasonable string which could refer to a structure to be
+	 * correctly parsed. The following are currently supported:
+	 * <ol>
+	 * <li>Filename (if name refers to an existing file)
+	 * <li>PDB ID
+	 * <li>SCOP domains
+	 * <li>PDP domains
+	 * <li>Residue ranges
+	 * <li>Other formats supported by AtomCache
+	 * </ol>
+	 * @param name Some reference to the protein structure
+	 * @param parser A clean PDBFileParser to use if it is a file. If null,
+	 * 	a PDBFileParser will be instantiated if needed.
+	 * @param cache An AtomCache to use if the structure can be fetched from the
+	 *  PDB.  If null, a AtomCache will be instantiated if needed.
+	 * @return A Structure object
+	 * @throws IOException if name is an existing file, but doesn't parse correctly
+	 * @throws StructureException if the format is unknown, or if AtomCache throws
+	 *  an exception.
+	 */
+	public static Structure getStructure(String name,PDBFileParser parser, AtomCache cache) throws IOException, StructureException {
+		File f = new File(FileDownloadUtils.expandUserHome(name));
+		if(f.exists()) {
+			if(parser == null) {
+				parser = new PDBFileParser();
+			}
+			InputStream inStream = new FileInputStream(f);
+			return parser.parsePDBFile(inStream);
+		} else {
+			if( cache == null) {
+				cache = new AtomCache();
+			}
+			return cache.getStructure(name);
+		}
+	}
 }
