@@ -3,8 +3,11 @@ package org.biojava.bio.structure.align.client;
 
 import java.io.Serializable;
 import java.io.StringWriter;
+import java.util.List;
 import java.util.regex.Matcher;
 
+import org.biojava.bio.structure.ResidueRange;
+import org.biojava.bio.structure.StructureIdentifier;
 import org.biojava.bio.structure.align.util.AtomCache;
 
 
@@ -12,7 +15,7 @@ import org.biojava.bio.structure.align.util.AtomCache;
  * 
  * @param name the name. e.g. 4hhb, 4hhb.A, d4hhba_, PDP:4HHBAa etc.
  */
-public class StructureName implements Comparable<StructureName>, Serializable{
+public class StructureName implements Comparable<StructureName>, Serializable, StructureIdentifier{
 
 	/**
 	 * 
@@ -34,7 +37,9 @@ public class StructureName implements Comparable<StructureName>, Serializable{
 
 
 	Source mySource = null; 
-
+	private  List<ResidueRange> ranges ;
+	
+	
 	public StructureName(String name){
 		if ( name.length() <  4)
 			throw new IllegalArgumentException("This is not a valid StructureName:" + name);
@@ -44,6 +49,12 @@ public class StructureName implements Comparable<StructureName>, Serializable{
 		this.pdbId = parsePdbId();
 
 		this.chainId = parseChainId();
+		
+		this.ranges = parseRanges();
+	}
+
+	private List<ResidueRange> parseRanges() {
+		return ResidueRange.parseMultiple(name);
 	}
 
 	/** PDB IDs are always returned as upper case
@@ -218,6 +229,30 @@ public class StructureName implements Comparable<StructureName>, Serializable{
 		return name.matches(cathPattern);
 	}
 
+	@Override
+	public String getIdentifier() {
+		return name;
+	}
+
+	@Override
+	public List<ResidueRange> getResidueRanges() {
+		return ranges;
+	}
+
+	@Override
+	public List<String> getRanges() {
+		return ResidueRange.toStrings(ranges);
+	}
+
+	public boolean hasRanges(){
+		return (ranges != null && ranges.size() > 0);
+	}
+	
+	public boolean isPdbId(){
+		if (name.length() == 4)
+			return true;
+		return false;
+	}
 
 
 }
