@@ -508,15 +508,22 @@ public class AFPChainXMLParser
 	private static int getPositionForPDBresunm(String pdbresnum, String chainId , Atom[] atoms){
 		ResidueNumber residueNumber =  ResidueNumber.fromString(pdbresnum);
 		residueNumber.setChainId(chainId);
+
+		boolean blankChain = chainId == null || chainId.equalsIgnoreCase("null") || chainId.equals("_");
 		
 		for ( int i =0; i< atoms.length ;i++){
 			Group g = atoms[i].getGroup();
-			
+
+			// match _ to any chain
+			if( blankChain ) {
+				residueNumber.setChainId(g.getChainId());
+			}
+
 			//System.out.println(g.getResidueNumber() + "< ? >" + residueNumber +"<");
 			if ( g.getResidueNumber().equals(residueNumber)){
 				//System.out.println(g + " == " + residueNumber );
 				Chain c = g.getChain();
-				if ( c.getChainID().equals(chainId)){
+				if ( blankChain || c.getChainID().equals(chainId)){
 					return i;
 				}
 			}
