@@ -7,7 +7,7 @@ import org.biojava.bio.structure.Structure;
 import org.biojava.bio.structure.StructureTools;
 import org.biojava.bio.structure.align.util.AtomCache;
 import org.biojava.bio.structure.io.FileParsingParameters;
-import org.biojava.bio.structure.quaternary.ModelTransformationMatrix;
+import org.biojava.bio.structure.quaternary.BiologicalAssemblyTransformation;
 import org.biojava3.core.util.SoftHashMap;
 
 
@@ -79,7 +79,7 @@ public class PDBBioUnitDataProvider implements BioUnitDataProvider{
 	}
 	
 	@Override
-	public List<ModelTransformationMatrix> getBioUnitTransformationList(
+	public List<BiologicalAssemblyTransformation> getBioUnitTransformationList(
 			String pdbId, int biolAssemblyNr) {
 
 	
